==> entity_media_usage-1.0.3.tar.gz: entity_media_usage/src/Routing/RouteSubscriber.php <==
<?php

namespace Drupal\entity_media_usage\Routing;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Subscriber for entity_media_usage routes.
 */
class RouteSubscriber extends RouteSubscriberBase {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new RouteSubscriber object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_manager) {
    $this->entityTypeManager = $entity_manager;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if ($route = $this->getMediaUsageListRoute($entity_type)) {
        $collection->add("entity.$entity_type_id.media_usage", $route);
      }
    }
  }

  /**
   * Gets the entity load route.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type.
   *
   * @return \Symfony\Component\Routing\Route|null
   *   The generated route, if available.
   */
  protected function getMediaUsageListRoute(EntityTypeInterface $entity_type) {
    if ($media_usage = $entity_type->getLinkTemplate('media-usage')) {
      $entity_type_id = $entity_type->id();
      $route          = new Route($media_usage);
      $route
        ->addDefaults([
          '_controller' => '\Drupal\entity_media_usage\Controller\EntityMediaUsageController::list',
          '_title'      => 'Media usage',
        ])
        ->addRequirements([
          '_permission' => 'access entity_media_usage information',
        ])
        ->setOption('_admin_route', TRUE)
        ->setOption('_media_usage_entity_type_id', $entity_type_id)
        ->setOption('parameters', [
          $entity_type_id => ['type' => 'entity:' . $entity_type_id],
        ]);

      return $route;
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events                       = parent::getSubscribedEvents();
    $events[RoutingEvents::ALTER] = ['onAlterRoutes', 100];
    return $events;
  }

}

==> entity_media_usage-1.0.4.tar.gz: entity_media_usage/src/Routing/RouteSubscriber.php <==
<?php

namespace Drupal\entity_media_usage\Routing;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Subscriber for entity_media_usage routes.
 */
class RouteSubscriber extends RouteSubscriberBase {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new RouteSubscriber object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if ($route = $this->getMediaUsageListRoute($entity_type)) {
        $collection->add("entity.$entity_type_id.media_usage", $route);
      }
    }
  }

  /**
   * Gets the entity load route.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type.
   *
   * @return \Symfony\Component\Routing\Route|null
   *   The generated route, if available.
   */
  protected function getMediaUsageListRoute(EntityTypeInterface $entity_type) {
    if ($media_usage = $entity_type->getLinkTemplate('media_usage')) {
      $entity_type_id = $entity_type->id();
      $route          = new Route($media_usage);
      $route
        ->addDefaults([
          '_controller' => '\Drupal\entity_media_usage\Controller\EntityMediaUsageController::list',
          '_title'      => 'Media usage',
        ])
        ->addRequirements([
          '_permission' => 'access entity_media_usage information',
        ])
        ->setOption('_admin_route', TRUE)
        ->setOption('_media_usage_entity_type_id', $entity_type_id)
        ->setOption('parameters', [
          $entity_type_id => ['type' => 'entity:' . $entity_type_id],
        ]);

      return $route;
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events                       = parent::getSubscribedEvents();
    $events[RoutingEvents::ALTER] = ['onAlterRoutes', 100];
    return $events;
  }

}
